@@ -27,6 +27,9 @@ from poliastro import constants
 
 
 class _Body(object):
+    name: str
+    symbol: str
+
     def __str__(self):
         return f"{self.name} ({self.symbol})"
 
