@@ -4,14 +4,15 @@ Wraps numba if it is available as a module, uses an identity
 decorator instead.
 
 """
-import warnings
 import inspect
+import warnings
 
 
 def ijit(first=None, *args, **kwargs):
     """Identity JIT, returns unchanged function.
 
     """
+
     def _jit(f):
         return f
 
@@ -23,10 +24,13 @@ def ijit(first=None, *args, **kwargs):
 
 try:
     import numba
+
     jit = numba.njit
 except ImportError:
-    warnings.warn("Could not import numba package. All poliastro "
-                  "functions will work properly but the CPU intensive "
-                  "algorithms will be slow. Consider installing numba to "
-                  "boost performance.")
+    warnings.warn(
+        "Could not import numba package. All poliastro "
+        "functions will work properly but the CPU intensive "
+        "algorithms will be slow. Consider installing numba to "
+        "boost performance."
+    )
     jit = ijit
