@@ -28,7 +28,9 @@ def beta_0(V_0, V_f, inc_0, inc_f):
     """Compute initial yaw angle (β) as a function of the problem parameters.
     """
     delta_i_f = abs(inc_f - inc_0)
-    return np.arctan2(np.sin(np.pi / 2 * delta_i_f), V_0 / V_f - np.cos(np.pi / 2 * delta_i_f))
+    return np.arctan2(
+        np.sin(np.pi / 2 * delta_i_f), V_0 / V_f - np.cos(np.pi / 2 * delta_i_f)
+    )
 
 
 @jit
@@ -48,4 +50,6 @@ def delta_V(V_0, beta_0, inc_0, inc_f):
     """Compute required increment of velocity.
     """
     delta_i_f = abs(inc_f - inc_0)
-    return V_0 * np.cos(beta_0) - V_0 * np.sin(beta_0) / np.tan(np.pi / 2 * delta_i_f + beta_0)
+    return V_0 * np.cos(beta_0) - V_0 * np.sin(beta_0) / np.tan(
+        np.pi / 2 * delta_i_f + beta_0
+    )
