@@ -205,9 +205,7 @@ class CZMLExtractor:
         pckt = Packet(
             id="GS" + str(self.gs_n),
             description=id_description,
-            availability=TimeInterval(
-                start=self.start_epoch.datetime, end=self.end_epoch.datetime
-            ),
+            availability=TimeInterval(start=self.start_epoch, end=self.end_epoch),
             position=Position(cartesian=pos),
             label=Label(
                 show=label_show,
@@ -312,9 +310,7 @@ class CZMLExtractor:
             id=self.i,
             name=id_name,
             description=id_description,
-            availability=TimeInterval(
-                start=self.start_epoch.datetime, end=self.end_epoch.datetime
-            ),
+            availability=TimeInterval(start=self.start_epoch, end=self.end_epoch),
             position=Position(
                 interpolationDegree=5,
                 interpolationAlgorithm=InterpolationAlgorithms.LAGRANGE,
