@@ -15,18 +15,19 @@ def _fake_numba_import():
 
         def find_module(self, fullname, *args, **kwargs):
             if fullname in self.modules:
-                raise ImportError('Debug import failure for %s' % fullname)
+                raise ImportError("Debug import failure for %s" % fullname)
 
-    fail_loader = FakeImportFailure(['numba'])
+    fail_loader = FakeImportFailure(["numba"])
 
     import poliastro.core._jit
     from poliastro.core import _jit
+
     del poliastro.core._jit
     del _jit
-    del sys.modules['poliastro.core._jit']
+    del sys.modules["poliastro.core._jit"]
 
-    if 'numba' in sys.modules:
-        del sys.modules['numba']
+    if "numba" in sys.modules:
+        del sys.modules["numba"]
 
     sys.meta_path.insert(0, fail_loader)
 
@@ -38,6 +39,7 @@ def _fake_numba_import():
 def test_ijit_returns_same_function_without_args():
     def expected_foo():
         return True
+
     foo = _jit.ijit(expected_foo)
     assert foo is expected_foo
 
@@ -45,13 +47,14 @@ def test_ijit_returns_same_function_without_args():
 def test_ijit_returns_same_function_with_args():
     def expected_foo():
         return True
+
     foo = _jit.ijit(1)(expected_foo)
     assert foo is expected_foo
 
 
 def test_no_numba_emits_warning(recwarn):
     with _fake_numba_import():
-        from poliastro.core import _jit  # flake8: noqa
+        from poliastro.core import _jit  # noqa
 
         assert len(recwarn) == 1
         w = recwarn.pop(UserWarning)
