@@ -1,16 +1,18 @@
 import pytest
-
-from astropy.tests.helper import assert_quantity_allclose
 from astropy import units as u
+from astropy.tests.helper import assert_quantity_allclose
 
 from poliastro.bodies import Venus
 from poliastro.threebody.flybys import compute_flyby
 
 
-@pytest.mark.parametrize("theta, expected_V_2_v", [
-    (0 * u.deg, [31.73, 1.766, 0] * u.km / u.s),
-    (180 * u.deg, [37.14, -3.074, 0] * u.km / u.s),
-])
+@pytest.mark.parametrize(
+    "theta, expected_V_2_v",
+    [
+        (0 * u.deg, [31.73, 1.766, 0] * u.km / u.s),
+        (180 * u.deg, [37.14, -3.074, 0] * u.km / u.s),
+    ],
+)
 def test_flyby_curtis(theta, expected_V_2_v):
     # Data from Curtis, Example 8.6
     periapsis_h = 300 * u.km
